# R script for conducting an analysis as the one reported in the
# slides on network dynamics: the evolution of advice seeking
# is explained by (among other effects) friendship, and sender
# & receiver effects of performance.
#
# Lawrence, 22 June 2011, Christian Steglich.

# Load Siena commands:
library(RSiena)

# Change working directory:
setwd('<put here the path to where your data are>')
# (replace single backslashes '\' by double backslashes '\\')
list.files()

# Read data sets; first three waves of dependent advice network:
advice1 <- as.matrix(read.table("MBA-Advice1.txt"))
advice2 <- as.matrix(read.table("MBA-Advice2.txt"))
advice3 <- as.matrix(read.table("MBA-Advice3.txt"))
# Next two waves of time-varying covariate network friendship:
friend1 <- as.matrix(read.table("MBA-Friendship1.txt"))
friend2 <- as.matrix(read.table("MBA-Friendship2.txt"))
# Now performance and covariates:
perf <- as.matrix(read.table("MBA-Performance.txt"))
attrib <- as.matrix(read.table("MBA-Covariates.txt"))

# Sort data into roles for analysis; first dependent network:
advice <- sienaNet(array(c(advice1,advice2,advice3),dim=c(75,75,3)))
# Next predictor network:
friendship <- varDyadCovar(array(c(friend1,friend2),dim=c(75,75,2)))
# Time-varying covariate 'performance' (first two measures):
performance <- varCovar(perf[,1:2])
# Constant covariates:
background <- coCovar(attrib[,4])
experience <- coCovar(attrib[,5])

# Combine into data package for Siena analysis:
adv.data <- sienaDataCreate(advice,friendship,performance,background,experience)

# Create effects object for model specification:
adv.eff <- getEffects(adv.data)

# Write file with initial descriptives:
print01Report(adv.data,adv.eff,modelname='advice-init')

# Specify model; first some control variables that instantiate
# interdependence; transitivity, 3-cycles, and a "Matthew effect":
adv.eff <- includeEffects(adv.eff,transTrip,cycle3,inPop)
# Hypothesis "You ask advice from your friends":
adv.eff <- includeEffects(adv.eff,X,interaction1="friendship")
# Two control variables: advice sought from those who have the same 
# study background before entering the MBA programme, and from those
# who share job experience status: 
adv.eff <- includeEffects(adv.eff,sameX,interaction1="background")
adv.eff <- includeEffects(adv.eff,sameX,interaction1="experience")
# Hypotheses: low performers need advice; high performers a asked for it:
adv.eff <- includeEffects(adv.eff,egoX,altX,interaction1="performance")
# One more control variable: advice-related homophily:
adv.eff <- includeEffects(adv.eff,simX,interaction1="performance")

# Create model object:
adv.mod <- sienaModelCreate(useStdInits=TRUE,projname="adv.res-full")

# Estimate the model:
adv.res <- siena07(adv.mod,data=adv.data,effects=adv.eff,batch=FALSE,verbose=FALSE)

# save results:
save.image("adv.res.RData")
